@@ -18,6 +18,7 @@ Examples:
     ...
     >>> class SimpleConfig(Config):
     ...     @MyProperty
+    ...     @staticmethod  # You can add this for Pylint complain (needs to be after @MyProperty)
     ...     def var() -> int:  # Type hints are validated.
     ...         '''
     ...         Type:
@@ -32,6 +33,7 @@ Examples:
     ...         return 123  # This is initial value that can be edited.
     ...
     ...     @MyProperty
+    ...     @staticmethod
     ...     def var_literal() -> Literal[1, 2, 3]:  # Literal options are also validated
     ...         return 2
     ...
@@ -39,11 +41,6 @@ Examples:
     ...     def evaluated(self) -> int | float:
     ...         return self.var + 1
     ...
-    ...
-    ...     @property   # If you need some logic in setter, use normal property
-    ...     def evaluated(self) -> int | float:
-    ...         return self.var + 1
-    ...
     >>> config = SimpleConfig()
     >>> config.var
     123
@@ -96,6 +93,7 @@ Note:
 ...
 ...         class SubSubConfiguration(Config):
 ...             @MyProperty
+...             @staticmethod
 ...             def value1() -> Literal[0, 1, 2, 3]:
 ...                 '''Documentation here
 ...
@@ -188,7 +186,14 @@ Now you can use in terminal like.
 
 
 Only basic types like int, float, str, list, dict, set are possible as eval for using type like numpy
-array or pandas dataframe could be security leak.
+array or pandas DataFrame could be security leak if eval would be used.
+
+Lists and tuples put inside brackets so it's not taken as more parameters.
+
+Setter
+======
+
+If you need extra logic in setters, use normal property or implement custom descriptors.
 
 Sphinx docs
 ===========
@@ -210,6 +215,9 @@ Here is example
     :alt: config_on_sphinx
     :align: center
 """
+# Because of doctest
+from __future__ import annotations
+
 from mypythontools.config.config_internal import Config
 from mypythontools.property import MyProperty
 
